@@ -14,17 +14,16 @@ import csv
 import logging
 import re
 import sys
-from time import sleep
 import xml.etree.ElementTree as et  # nosec
+from time import sleep
 
 import bs4
 import requests
-from six.moves import configparser
 import yaml
+from six.moves import configparser
 
 from lftools import config
-from lftools.nexus import Nexus
-from lftools.nexus import util
+from lftools.nexus import Nexus, util
 
 log = logging.getLogger(__name__)
 
@@ -85,7 +84,7 @@ def reorder_staged_repos(settings_file):
         settings = yaml.safe_load(f)
 
     for setting in ["nexus", "user", "password"]:
-        if not setting in settings:
+        if setting not in settings:
             log.error("{} needs to be defined".format(setting))
             sys.exit(1)
 
@@ -93,7 +92,7 @@ def reorder_staged_repos(settings_file):
 
     try:
         repo_id = _nexus.get_repo_group("Staging Repositories")
-    except LookupError as e:
+    except LookupError:
         log.error("Staging repository 'Staging Repositories' cannot be found")
         sys.exit(1)
 
@@ -137,13 +136,13 @@ def create_repos(config_file, settings_file, url):
             settings = yaml.safe_load(f)
 
     for setting in ["email_domain", "base_groupId", "repositories"]:
-        if not setting in config:
+        if setting not in config:
             log.error("{} needs to be defined in {}".format(setting, config_file))
             sys.exit(1)
 
     if settings_file:
         for setting in ["nexus", "user", "password"]:
-            if not setting in settings:
+            if setting not in settings:
                 log.error("{} needs to be defined in {}".format(setting, settings_file))
                 sys.exit(1)
 
@@ -156,7 +155,7 @@ def create_repos(config_file, settings_file, url):
         # Create target
         try:
             target_id = _nexus.get_target(name)
-        except LookupError as e:
+        except LookupError:
             target_id = _nexus.create_target(name, targets)
 
         # Create privileges
@@ -172,21 +171,21 @@ def create_repos(config_file, settings_file, url):
             try:
                 privs[priv] = _nexus.get_priv(name, priv)
                 log.info("Creating {} privileges.".format(priv))
-            except LookupError as e:
+            except LookupError:
                 privs[priv] = _nexus.create_priv(name, target_id, priv)
 
         # Create Role
         try:
             role_id = _nexus.get_role(name)
             log.info("Role {} already exists.".format(role_id))
-        except LookupError as e:
+        except LookupError:
             role_id = _nexus.create_role(name, privs)
 
         # Create user
         try:
             _nexus.get_user(name)
             log.info("User {} already exists.".format(name))
-        except LookupError as e:
+        except LookupError:
             _nexus.create_user(name, email, role_id, password, extra_privs)
 
     def build_repo(repo, repoId, config, base_groupId, global_privs, email_domain, strict=True):
@@ -194,7 +193,7 @@ def create_repos(config_file, settings_file, url):
         groupId = "{}.{}".format(base_groupId, repo)
         target = util.create_repo_target_regex(groupId, strict)
 
-        if not global_privs and not "extra_privs" in config:
+        if not global_privs and "extra_privs" not in config:
             extra_privs = []
         elif global_privs:
             extra_privs = global_privs
