@@ -42,10 +42,10 @@ from __future__ import print_function
 
 import logging
 import multiprocessing
-from multiprocessing.dummy import Pool as ThreadPool
+import os
 import re
 import socket
-import os
+from multiprocessing.dummy import Pool as ThreadPool
 
 import docker
 import requests
@@ -400,7 +400,7 @@ class ProjectClass:
 
         if len(self.nexus_tags.valid) > 0:
             for nexustag in self.nexus_tags.valid:
-                if not nexustag in self.docker_tags.valid:
+                if nexustag not in self.docker_tags.valid:
                     log.debug("Need to copy tag {} from {}".format(nexustag, self.nexus_repo_name))
                     self.tags_2_copy.add_tag(nexustag)
 
